@@ -1,3 +1,4 @@
+from django.conf import settings
 from django.db import models
 from django.forms.widgets import Select
 from django.shortcuts import render
@@ -11,13 +12,15 @@ from .utils import JotFormAPI
 
 
 def jot_form_choices():
-    data = JotFormAPI()
-    data.fetch_from_api()
-    data = data.get_data()
     jot_form_data = []
-    if data and "content" in data:
-        for item in data["content"]:
-            jot_form_data.append((item["id"], item["title"]))
+    if settings.JOTFORM_API_URL and settings.JOTFORM_API_KEY:
+        data = JotFormAPI()
+        data.fetch_from_api()
+        data = data.get_data()
+
+        if data and "content" in data:
+            for item in data["content"]:
+                jot_form_data.append((item["id"], item["title"]))
     return jot_form_data
 
 
