@@ -4,7 +4,7 @@ from django.conf import settings
 from django.core.cache import cache
 
 import requests
-from requests.exceptions import ConnectionError, HTTPError, Timeout
+from requests.exceptions import ConnectionError, HTTPError, MissingSchema, Timeout
 
 logger = logging.getLogger(__name__)
 
@@ -23,6 +23,9 @@ def fetch_data(url, headers=None, **params):
     except (HTTPError, ConnectionError):
         logger.exception(f"HTTP/ConnectionError occured when fetching data from {url}")
         raise CantPullFromAPI(f"Error occured when fetching data from {url}")
+    except MissingSchema as e:
+        logger.exception(f"HTTP/ConnectionError occured when fetching data: {e}")
+        raise CantPullFromAPI(f"Error occured when fetching data from {url}")
     except Exception:
         logger.exception(f"Exception occured when fetching data from {url}")
         raise CantPullFromAPI(f"Error occured when fetching data from {url}")
